# NOTE: This file is auto generated by OpenAPI Generator 7.13.0-SNAPSHOT (https://openapi-generator.tech).
# Do not edit this file manually.

defmodule WelcomeToZembraAPIDocumentation.Api.Batch do
  @moduledoc """
  API calls for all endpoints tagged `Batch`.
  """

  alias WelcomeToZembraAPIDocumentation.Connection
  import WelcomeToZembraAPIDocumentation.RequestBuilder

  @doc """
  Create Batch
  Instead of running parallel requests or looping over your records and submitting one request at a time, you can choose to submit up to 1,000 requests in bulk. The server will pre-validate the inputs and accept all valid requests from the batch. <br><br>Every request included in the batch will be processed and its result stored and if applicable delivered to your listeners. You can always retrieve the output of each request individually. <br><br>To prevent congestion, you can only submit 1 batch per minute. <br><br>Same options from the original endpoint can be used. Example, for **[POST] /batch/listing/details** your payload will look like this `[{\"network\": \"google\", \"slug\": \"my-listing\"}]`. <br><br>Below is the mapping of batch endpoints to regular endpoints: | **Batch Endpoint**  | **Original Endpoint** | |-----------------|-------------------| | /batch/listing/details | **[GET]** /listing/{network} | | /batch/listing/find  | **[GET]** /listing/find  | | /batch/listing/match | **[GET]** /listing/match | | /batch/reviews  | **[POST]** /reviews | | /batch/social/details | **[POST]** /social/{network}/{resource}/{slug}  | | /batch/social/job | **[POST]** /social/job/{network}/{resource}/{slug}/{content}  | | /batch/social/subscription | **[POST]** /social/subscription/{network}/{resource}/{slug}/{content} | 

  ### Parameters

  - `connection` (WelcomeToZembraAPIDocumentation.Connection): Connection to server
  - `service` (String.t): One of the major service categories.
  - `sub_service` (String.t): The specific endpoint alias.
  - `create_batch_request_inner` ([WelcomeToZembraAPIDocumentation.Model.CreateBatchRequestInner.t]): An array of raw request objects. Fields vary per requested service.
  - `opts` (keyword): Optional parameters

  ### Returns

  - `{:ok, WelcomeToZembraAPIDocumentation.Model.CreateBatch201Response.t}` on success
  - `{:error, Tesla.Env.t}` on failure
  """
  @spec create_batch(Tesla.Env.client, String.t, String.t, list(WelcomeToZembraAPIDocumentation.Model.CreateBatchRequestInner.t), keyword()) :: {:ok, WelcomeToZembraAPIDocumentation.Model.CreateBatch201Response.t} | {:ok, WelcomeToZembraAPIDocumentation.Model.GetPropertyDetailsByName401Response.t} | {:ok, WelcomeToZembraAPIDocumentation.Model.CreateBatch400Response.t} | {:ok, WelcomeToZembraAPIDocumentation.Model.GetPropertyDetailsByName403Response.t} | {:error, Tesla.Env.t}
  def create_batch(connection, service, sub_service, create_batch_request_inner, _opts \\ []) do
    request =
      %{}
      |> method(:post)
      |> url("/batch/#{service}/#{sub_service}")
      |> add_param(:body, :body, create_batch_request_inner)
      |> Enum.into([])

    connection
    |> Connection.request(request)
    |> evaluate_response([
      {201, WelcomeToZembraAPIDocumentation.Model.CreateBatch201Response},
      {400, WelcomeToZembraAPIDocumentation.Model.CreateBatch400Response},
      {401, WelcomeToZembraAPIDocumentation.Model.GetPropertyDetailsByName401Response},
      {403, WelcomeToZembraAPIDocumentation.Model.GetPropertyDetailsByName403Response}
    ])
  end

  @doc """
  Get Batch Entry Result
  Get the status and, if completed, the result of a request.

  ### Parameters

  - `connection` (WelcomeToZembraAPIDocumentation.Connection): Connection to server
  - `batch_id` (String.t): The generated batchID that was returned by the API when the batch was submitted.
  - `request_index` (integer()): The index of the request from the originally submitted array. The index starts from 1 and can be at most 1000 where 1 stands for the first request.
  - `opts` (keyword): Optional parameters

  ### Returns

  - `{:ok, WelcomeToZembraAPIDocumentation.Model.GetBatchEntryResult200Response.t}` on success
  - `{:error, Tesla.Env.t}` on failure
  """
  @spec get_batch_entry_result(Tesla.Env.client, String.t, integer(), keyword()) :: {:ok, WelcomeToZembraAPIDocumentation.Model.GetPropertyDetailsByName401Response.t} | {:ok, WelcomeToZembraAPIDocumentation.Model.GetBatchStatus410Response.t} | {:ok, WelcomeToZembraAPIDocumentation.Model.GetBatchEntryResult200Response.t} | {:ok, WelcomeToZembraAPIDocumentation.Model.GetBatchEntryResult404Response.t} | {:error, Tesla.Env.t}
  def get_batch_entry_result(connection, batch_id, request_index, _opts \\ []) do
    request =
      %{}
      |> method(:get)
      |> url("/batch/#{batch_id}/#{request_index}")
      |> Enum.into([])

    connection
    |> Connection.request(request)
    |> evaluate_response([
      {200, WelcomeToZembraAPIDocumentation.Model.GetBatchEntryResult200Response},
      {401, WelcomeToZembraAPIDocumentation.Model.GetPropertyDetailsByName401Response},
      {404, WelcomeToZembraAPIDocumentation.Model.GetBatchEntryResult404Response},
      {410, WelcomeToZembraAPIDocumentation.Model.GetBatchStatus410Response}
    ])
  end

  @doc """
  Get Batch List
  Get the list of all the batches previously accepted.

  ### Parameters

  - `connection` (WelcomeToZembraAPIDocumentation.Connection): Connection to server
  - `opts` (keyword): Optional parameters
    - `:limit` (integer()): Maximum number of batches to be returned. At most 100 batches will be returned even if this parameter is set to a higher value.
    - `:offset` (integer()): Helps with pagination. It controls the offset to be applied to the set of batches.
    - `:sortBy` (String.t): Indicates the desired sorting attribute.
    - `:sortDirection` (String.t): Indicates the desired sorting direction.
    - `:service` (String.t): Filter results to only batches that match the requested service.
    - `:subService` (String.t): Filter results to only batches that match the request sub-service.
    - `:status` (String.t): Filters by batch status.

  ### Returns

  - `{:ok, WelcomeToZembraAPIDocumentation.Model.GetBatchList200Response.t}` on success
  - `{:error, Tesla.Env.t}` on failure
  """
  @spec get_batch_list(Tesla.Env.client, keyword()) :: {:ok, WelcomeToZembraAPIDocumentation.Model.GetBatchList200Response.t} | {:ok, WelcomeToZembraAPIDocumentation.Model.GetPropertyDetailsByName401Response.t} | {:ok, WelcomeToZembraAPIDocumentation.Model.GetBatchList400Response.t} | {:error, Tesla.Env.t}
  def get_batch_list(connection, opts \\ []) do
    optional_params = %{
      :limit => :query,
      :offset => :query,
      :sortBy => :query,
      :sortDirection => :query,
      :service => :query,
      :subService => :query,
      :status => :query
    }

    request =
      %{}
      |> method(:get)
      |> url("/batches")
      |> add_optional_params(optional_params, opts)
      |> Enum.into([])

    connection
    |> Connection.request(request)
    |> evaluate_response([
      {200, WelcomeToZembraAPIDocumentation.Model.GetBatchList200Response},
      {400, WelcomeToZembraAPIDocumentation.Model.GetBatchList400Response},
      {401, WelcomeToZembraAPIDocumentation.Model.GetPropertyDetailsByName401Response}
    ])
  end

  @doc """
  Get Batch Status
  This endpoint will provide details about the batch like requested time, overall progress, list of completed requests, etc.

  ### Parameters

  - `connection` (WelcomeToZembraAPIDocumentation.Connection): Connection to server
  - `batch_id` (String.t): The generated batchID that was returned by the API when the batch was submitted.
  - `opts` (keyword): Optional parameters

  ### Returns

  - `{:ok, WelcomeToZembraAPIDocumentation.Model.GetBatchStatus200Response.t}` on success
  - `{:error, Tesla.Env.t}` on failure
  """
  @spec get_batch_status(Tesla.Env.client, String.t, keyword()) :: {:ok, WelcomeToZembraAPIDocumentation.Model.GetPropertyDetailsByName401Response.t} | {:ok, WelcomeToZembraAPIDocumentation.Model.GetBatchStatus410Response.t} | {:ok, WelcomeToZembraAPIDocumentation.Model.GetBatchStatus404Response.t} | {:ok, WelcomeToZembraAPIDocumentation.Model.GetBatchStatus200Response.t} | {:error, Tesla.Env.t}
  def get_batch_status(connection, batch_id, _opts \\ []) do
    request =
      %{}
      |> method(:get)
      |> url("/batch/#{batch_id}")
      |> Enum.into([])

    connection
    |> Connection.request(request)
    |> evaluate_response([
      {200, WelcomeToZembraAPIDocumentation.Model.GetBatchStatus200Response},
      {401, WelcomeToZembraAPIDocumentation.Model.GetPropertyDetailsByName401Response},
      {404, WelcomeToZembraAPIDocumentation.Model.GetBatchStatus404Response},
      {410, WelcomeToZembraAPIDocumentation.Model.GetBatchStatus410Response}
    ])
  end
end
