# NOTE: This file is auto generated by OpenAPI Generator 7.13.0-SNAPSHOT (https://openapi-generator.tech).
# Do not edit this file manually.

defmodule WelcomeToZembraAPIDocumentation.Api.Listing do
  @moduledoc """
  API calls for all endpoints tagged `Listing`.
  """

  alias WelcomeToZembraAPIDocumentation.Connection
  import WelcomeToZembraAPIDocumentation.RequestBuilder

  @doc """
  Listings Lookup
  Get the list of listings, i.e. review pages, that match the search query from the given list of networks. The search query consists of the name of the business or its category, and optionally the address. If the listing is found, the response contains a list of up to **10** listings per network. You can also limit the list of fields to be returned. Data like images, exact address, review count, etc. might be missing on some networks. This service returns fewer details compared to querying listing details which performs a more in-depth lookup. <br><br>Note that networks **Expedia**, **Orbitz**, and **Travelocity** belong to the same group and use the same data and format. As a result, you might be getting data for *Expedia* showing URL on Orbitz but all info and reviews are valid and taken straight from the requested source. 

  ### Parameters

  - `connection` (WelcomeToZembraAPIDocumentation.Connection): Connection to server
  - `name` (String.t): Name of the business or in some cases the listing category
  - `opts` (keyword): Optional parameters
    - `:address` (String.t): One-line formatted address of the business. For some networks, the more precise is the address, the more accurate are the results. Nevertheless, in most of the cases the city is sufficient. The behavior and results are identical to running the same lookup command against the native site. Before questioning why no data is being returned by the API, please first confirm against the original platform.
    - `:"networks[]"` ([WelcomeToZembraAPIDocumentation.Model.ReviewNetwork.t]): Optional field to restrict the search query to a limited set of networks. If omitted, the search covers all networks enabled for the account. Not all networks support this search feature. Your account will only be charged for supported networks.
    - `:"fields[]"` ([WelcomeToZembraAPIDocumentation.Model.ReviewPageField.t]): List of fields to be returned per listing

  ### Returns

  - `{:ok, WelcomeToZembraAPIDocumentation.Model.FindListings200Response.t}` on success
  - `{:error, Tesla.Env.t}` on failure
  """
  @spec find_listings(Tesla.Env.client, String.t, keyword()) :: {:ok, WelcomeToZembraAPIDocumentation.Model.GetPropertyDetailsByName402Response.t} | {:ok, WelcomeToZembraAPIDocumentation.Model.GetListingDetails404Response.t} | {:ok, WelcomeToZembraAPIDocumentation.Model.GetPropertyDetailsByName401Response.t} | {:ok, WelcomeToZembraAPIDocumentation.Model.FindListings200Response.t} | {:ok, WelcomeToZembraAPIDocumentation.Model.FindListings400Response.t} | {:ok, WelcomeToZembraAPIDocumentation.Model.GetPropertyDetailsByName403Response.t} | {:error, Tesla.Env.t}
  def find_listings(connection, name, opts \\ []) do
    optional_params = %{
      :address => :query,
      :"networks[]" => :query,
      :"fields[]" => :query
    }

    request =
      %{}
      |> method(:get)
      |> url("/listing/find")
      |> add_param(:query, :name, name)
      |> add_optional_params(optional_params, opts)
      |> Enum.into([])

    connection
    |> Connection.request(request)
    |> evaluate_response([
      {200, WelcomeToZembraAPIDocumentation.Model.FindListings200Response},
      {400, WelcomeToZembraAPIDocumentation.Model.FindListings400Response},
      {401, WelcomeToZembraAPIDocumentation.Model.GetPropertyDetailsByName401Response},
      {402, WelcomeToZembraAPIDocumentation.Model.GetPropertyDetailsByName402Response},
      {403, WelcomeToZembraAPIDocumentation.Model.GetPropertyDetailsByName403Response},
      {404, WelcomeToZembraAPIDocumentation.Model.GetListingDetails404Response}
    ])
  end

  @doc """
  Listing Match
  Using the business name and address, find the exact business profile page on the list of networks of your choice. If the listing is found, this endpoint returns at most one review page per network representing the matching listing page. Data and content are the same as returned by the **Find Listing** endpoint. <br><br>This service is great for finding the exact pages of the same business on multiple platforms at once. The match is guaranteed to be precise. There could be some misses due to insufficient data to confirm the match. 

  ### Parameters

  - `connection` (WelcomeToZembraAPIDocumentation.Connection): Connection to server
  - `name` (String.t): Name of the business, preferably as it appears on the review platform
  - `address` (String.t): One-line formatted address of the business. For some networks, the more precise is the address, the more accurate are the results. Nevertheless, in most of the cases the city is sufficient. Can be omitted if the user prefers to specify address components: `street`, `city`, `region`, `postalCode`, and `country`.
  - `street` (String.t): The street and street number of the business. Optionally, the unit/suite number can be appended. Required if parameter `address` is missing.
  - `city` (String.t): The city where the business is located. Required if parameter `address` is missing.
  - `postal_code` (String.t): Postal code or zipcode of the business. Required if parameter `address` is missing.
  - `country` (String.t): The country where the business operates. Required if parameter `address` is missing.
  - `opts` (keyword): Optional parameters
    - `:region` (String.t): The state, province, or any regional/political area that the city of the business belongs to.
    - `:"networks[]"` ([WelcomeToZembraAPIDocumentation.Model.ReviewNetwork.t]): Optional field to restrict the search query to a limited set of networks. If omitted, the search covers all networks enabled for the account.
    - `:"fields[]"` ([WelcomeToZembraAPIDocumentation.Model.ReviewPageField.t]): List of fields to be returned per listing

  ### Returns

  - `{:ok, WelcomeToZembraAPIDocumentation.Model.FindMatchingListing200Response.t}` on success
  - `{:error, Tesla.Env.t}` on failure
  """
  @spec find_matching_listing(Tesla.Env.client, String.t, String.t, String.t, String.t, String.t, String.t, keyword()) :: {:ok, WelcomeToZembraAPIDocumentation.Model.GetPropertyDetailsByName402Response.t} | {:ok, WelcomeToZembraAPIDocumentation.Model.GetListingDetails404Response.t} | {:ok, WelcomeToZembraAPIDocumentation.Model.GetPropertyDetailsByName401Response.t} | {:ok, WelcomeToZembraAPIDocumentation.Model.FindListings400Response.t} | {:ok, WelcomeToZembraAPIDocumentation.Model.FindMatchingListing200Response.t} | {:ok, WelcomeToZembraAPIDocumentation.Model.GetPropertyDetailsByName403Response.t} | {:error, Tesla.Env.t}
  def find_matching_listing(connection, name, address, street, city, postal_code, country, opts \\ []) do
    optional_params = %{
      :region => :query,
      :"networks[]" => :query,
      :"fields[]" => :query
    }

    request =
      %{}
      |> method(:get)
      |> url("/listing/match")
      |> add_param(:query, :name, name)
      |> add_param(:query, :address, address)
      |> add_param(:query, :street, street)
      |> add_param(:query, :city, city)
      |> add_param(:query, :postalCode, postal_code)
      |> add_param(:query, :country, country)
      |> add_optional_params(optional_params, opts)
      |> Enum.into([])

    connection
    |> Connection.request(request)
    |> evaluate_response([
      {200, WelcomeToZembraAPIDocumentation.Model.FindMatchingListing200Response},
      {400, WelcomeToZembraAPIDocumentation.Model.FindListings400Response},
      {401, WelcomeToZembraAPIDocumentation.Model.GetPropertyDetailsByName401Response},
      {402, WelcomeToZembraAPIDocumentation.Model.GetPropertyDetailsByName402Response},
      {403, WelcomeToZembraAPIDocumentation.Model.GetPropertyDetailsByName403Response},
      {404, WelcomeToZembraAPIDocumentation.Model.GetListingDetails404Response}
    ])
  end

  @doc """
  Listing Details
  Returns information about the business as presented on the requested network. On a few networks, data like exact address (Glassdoor) or images might be missing. The information returned by this endpoint is richer than data returned by the **Find Listings** and **Match Listing** endpoints.

  ### Parameters

  - `connection` (WelcomeToZembraAPIDocumentation.Connection): Connection to server
  - `network` (ReviewNetwork): Network the listing belongs to
  - `slug` (String.t): 
  - `opts` (keyword): Optional parameters
    - `:"fields[]"` ([WelcomeToZembraAPIDocumentation.Model.ReviewPageField.t]): Sub-list of fields to be returned. If omitted, all the fields are returned.

  ### Returns

  - `{:ok, WelcomeToZembraAPIDocumentation.Model.GetListingDetails200Response.t}` on success
  - `{:error, Tesla.Env.t}` on failure
  """
  @spec get_listing_details(Tesla.Env.client, WelcomeToZembraAPIDocumentation.Model.ReviewNetwork.t, String.t, keyword()) :: {:ok, WelcomeToZembraAPIDocumentation.Model.GetPropertyDetailsByName402Response.t} | {:ok, WelcomeToZembraAPIDocumentation.Model.GetListingDetails404Response.t} | {:ok, WelcomeToZembraAPIDocumentation.Model.GetListingDetails400Response.t} | {:ok, WelcomeToZembraAPIDocumentation.Model.GetPropertyDetailsByName401Response.t} | {:ok, WelcomeToZembraAPIDocumentation.Model.GetListingDetails200Response.t} | {:ok, WelcomeToZembraAPIDocumentation.Model.GetPropertyDetailsByName403Response.t} | {:error, Tesla.Env.t}
  def get_listing_details(connection, network, slug, opts \\ []) do
    optional_params = %{
      :"fields[]" => :query
    }

    request =
      %{}
      |> method(:get)
      |> url("/listing/#{network}")
      |> add_param(:query, :slug, slug)
      |> add_optional_params(optional_params, opts)
      |> Enum.into([])

    connection
    |> Connection.request(request)
    |> evaluate_response([
      {200, WelcomeToZembraAPIDocumentation.Model.GetListingDetails200Response},
      {400, WelcomeToZembraAPIDocumentation.Model.GetListingDetails400Response},
      {401, WelcomeToZembraAPIDocumentation.Model.GetPropertyDetailsByName401Response},
      {402, WelcomeToZembraAPIDocumentation.Model.GetPropertyDetailsByName402Response},
      {403, WelcomeToZembraAPIDocumentation.Model.GetPropertyDetailsByName403Response},
      {404, WelcomeToZembraAPIDocumentation.Model.GetListingDetails404Response}
    ])
  end
end
