# NOTE: This file is auto generated by OpenAPI Generator 7.13.0-SNAPSHOT (https://openapi-generator.tech).
# Do not edit this file manually.

defmodule WelcomeToZembraAPIDocumentation.Api.SocialMedia do
  @moduledoc """
  API calls for all endpoints tagged `SocialMedia`.
  """

  alias WelcomeToZembraAPIDocumentation.Connection
  import WelcomeToZembraAPIDocumentation.RequestBuilder

  @doc """
  Create Social Media Job
  Creates a new job to stream data from the requested social media resource. It could be the comments list of an Instagram post or something similar. Data retention is set to 5 days. The data is not maintained up to date. The payload will be identical to the origin at the time of request. This is a snapshot of the current state of the requested resource. <br><br>If sizeLimit and/or dateLimit parameters are set, the streaming will be stopped as soon as one of the conditions is met. If none of these parameters is present, the streaming will continue until all content is downloaded. Omitting both parameters may cause your account to accrue large charges with busy sources. 

  ### Parameters

  - `connection` (WelcomeToZembraAPIDocumentation.Connection): Connection to server
  - `network` (SocialNetwork): Target social network
  - `resource` (Resource): Depending on the selected network, this will define what object you are trying to access details. <br><br>List of available resources varies by network: - **Better Business Bureau**:   - company - **Facebook**:   - advertiser   - page   - post - **Glassdoor**:   - company - **Instagram**:   - hashtag   - post   - user - **LinkedIn**:   - company   - keyword   - profile   - post - **Reddit**:   - keyword   - post   - subreddit   - user - **TikTok**:   - hashtag   - user   - video 
  - `slug` (String.t): Unique resource identifier. Full URLs are not accepted. Varies by network. Here are a few examples per resource: - **Better Business Bureau**:   - Company: good-greek-moving-storage-0633-90312345 - **Facebook**:   - Advertiser: 176105152520900   - Page: Presidence.tn   - Post: S:_I1391675561076747:3140064409571178 or 3140064409571178 or pfbid02ZZQHWhS4VQ3jwAN7FHbNtM5Hs1gAfkC6c6SoAkNvEsNNeY3e9gXVCKZPhg6WTnVTl - **Glassdoor**:   - Company: Working-at-Booz-Allen-Hamilton-EI_IE2735 - **Instagram**:   - Hashtag: coupleprayer   - Post: CFzAp7DASJ0   - User: soumaya_belkouchi - **LinkedIn**:   - Company: zembra   - Keyword: san+diego   - Profile: bakayoko   - Post: urn:li:ugcPost:6971444261015724033 - **Reddit**:   - Keyword: sandiego   - Post: 12mizot   - Subreddit: Damnthatsinteresting   - User: coastalJuncture - **TikTok**:   - Hashtag: healthy   - User: justqueen1988   - Video: 7114961878434041094 
  - `content` (Content): Depending on the selected network, this will define what data you want to stream. This is needed because under one source there could be more than one content type to be streamed. Example, for Instagram users, you may want to pull all comments or all reels.
  - `create_social_job_request` (CreateSocialJobRequest): 
  - `opts` (keyword): Optional parameters

  ### Returns

  - `{:ok, WelcomeToZembraAPIDocumentation.Model.CreateSocialJob201Response.t}` on success
  - `{:error, Tesla.Env.t}` on failure
  """
  @spec create_social_job(Tesla.Env.client, WelcomeToZembraAPIDocumentation.Model.SocialNetwork.t, WelcomeToZembraAPIDocumentation.Model.Resource.t, String.t, WelcomeToZembraAPIDocumentation.Model.Content.t, WelcomeToZembraAPIDocumentation.Model.CreateSocialJobRequest.t, keyword()) :: {:ok, WelcomeToZembraAPIDocumentation.Model.GetPropertyDetailsByName402Response.t} | {:ok, WelcomeToZembraAPIDocumentation.Model.GetSocialResourceDetails400Response.t} | {:ok, WelcomeToZembraAPIDocumentation.Model.GetSocialResourceDetails404Response.t} | {:ok, WelcomeToZembraAPIDocumentation.Model.GetPropertyDetailsByName401Response.t} | {:ok, WelcomeToZembraAPIDocumentation.Model.CreateSocialJob201Response.t} | {:ok, WelcomeToZembraAPIDocumentation.Model.GetPropertyDetailsByName403Response.t} | {:error, Tesla.Env.t}
  def create_social_job(connection, network, resource, slug, content, create_social_job_request, _opts \\ []) do
    request =
      %{}
      |> method(:post)
      |> url("/social/job/#{network}/#{resource}/#{slug}/#{content}")
      |> add_param(:body, :body, create_social_job_request)
      |> Enum.into([])

    connection
    |> Connection.request(request)
    |> evaluate_response([
      {201, WelcomeToZembraAPIDocumentation.Model.CreateSocialJob201Response},
      {400, WelcomeToZembraAPIDocumentation.Model.GetSocialResourceDetails400Response},
      {401, WelcomeToZembraAPIDocumentation.Model.GetPropertyDetailsByName401Response},
      {402, WelcomeToZembraAPIDocumentation.Model.GetPropertyDetailsByName402Response},
      {403, WelcomeToZembraAPIDocumentation.Model.GetPropertyDetailsByName403Response},
      {404, WelcomeToZembraAPIDocumentation.Model.GetSocialResourceDetails404Response}
    ])
  end

  @doc """
  Create Social Media Subscription
  Creates a new subscription to the requested social media resource stream. The subscription lasts 5 days. We monitor the resource for added elements, e.g. new comments posted. Data is kept current with a maximum of an 8 hour-gap with the source depending on how busy the source is. <br><br>All calls during the lifespan of the subscription to pull the data are free of charge. The cost of the subscription is based on the number of elements streamed in addition to a base service fee. There are no tiers per network. The same pricing applies to all networks. <br><br>If accepted, the response will include details about the requested resource and the `subscription` object with the requested settings. Once the subscription is created and if you desire to get the stream data, you can call the **[GET] /social/subscription/{network}/{resource}/{slug}/{content}** endpoint to retrieve the data. <br><br>You may need to allow a few minutes before getting the full list of elements. It takes as little as 1 second or sometimes 5 minutes for an average resource (~5000 comments) to be ready for delivery. Occasionally, the wait time may increase to 30 minutes and very rarely higher based on the **selected network**, the **number of elements**, and the status of the **social media platform servers**. <br><br>Once the data is fully ready, it will be delivered in chunks of up to 100 elements per call to your webhook. 

  ### Parameters

  - `connection` (WelcomeToZembraAPIDocumentation.Connection): Connection to server
  - `network` (SocialNetwork): Target social network
  - `resource` (Resource): Depending on the selected network, this will define what object you are trying to access details. <br><br>List of available resources varies by network: - **Better Business Bureau**:   - company - **Facebook**:   - advertiser   - page   - post - **Glassdoor**:   - company - **Instagram**:   - hashtag   - post   - user - **LinkedIn**:   - company   - keyword   - profile   - post - **Reddit**:   - keyword   - post   - subreddit   - user - **TikTok**:   - hashtag   - user   - video 
  - `slug` (String.t): Unique resource identifier. Full URLs are not accepted. Varies by network. Here are a few examples per resource: - **Better Business Bureau**:   - Company: good-greek-moving-storage-0633-90312345 - **Facebook**:   - Advertiser: 176105152520900   - Page: Presidence.tn   - Post: S:_I1391675561076747:3140064409571178 or 3140064409571178 or pfbid02ZZQHWhS4VQ3jwAN7FHbNtM5Hs1gAfkC6c6SoAkNvEsNNeY3e9gXVCKZPhg6WTnVTl - **Glassdoor**:   - Company: Working-at-Booz-Allen-Hamilton-EI_IE2735 - **Instagram**:   - Hashtag: coupleprayer   - Post: CFzAp7DASJ0   - User: soumaya_belkouchi - **LinkedIn**:   - Company: zembra   - Keyword: san+diego   - Profile: bakayoko   - Post: urn:li:ugcPost:6971444261015724033 - **Reddit**:   - Keyword: sandiego   - Post: 12mizot   - Subreddit: Damnthatsinteresting   - User: coastalJuncture - **TikTok**:   - Hashtag: healthy   - User: justqueen1988   - Video: 7114961878434041094 
  - `content` (Content): Depending on the selected network, this will define what data you want to stream. This is needed because under one source there could be more than one content type to be streamed. Example, for Instagram users, you may want to pull all comments or all reels.
  - `create_social_subscription_request` (CreateSocialSubscriptionRequest): 
  - `opts` (keyword): Optional parameters

  ### Returns

  - `{:ok, WelcomeToZembraAPIDocumentation.Model.CreateSocialSubscription201Response.t}` on success
  - `{:error, Tesla.Env.t}` on failure
  """
  @spec create_social_subscription(Tesla.Env.client, WelcomeToZembraAPIDocumentation.Model.SocialNetwork.t, WelcomeToZembraAPIDocumentation.Model.Resource.t, String.t, WelcomeToZembraAPIDocumentation.Model.Content.t, WelcomeToZembraAPIDocumentation.Model.CreateSocialSubscriptionRequest.t, keyword()) :: {:ok, WelcomeToZembraAPIDocumentation.Model.GetPropertyDetailsByName402Response.t} | {:ok, WelcomeToZembraAPIDocumentation.Model.GetSocialResourceDetails400Response.t} | {:ok, WelcomeToZembraAPIDocumentation.Model.GetSocialResourceDetails404Response.t} | {:ok, WelcomeToZembraAPIDocumentation.Model.GetPropertyDetailsByName401Response.t} | {:ok, WelcomeToZembraAPIDocumentation.Model.CreateSocialSubscription409Response.t} | {:ok, WelcomeToZembraAPIDocumentation.Model.CreateSocialSubscription201Response.t} | {:ok, WelcomeToZembraAPIDocumentation.Model.GetPropertyDetailsByName403Response.t} | {:error, Tesla.Env.t}
  def create_social_subscription(connection, network, resource, slug, content, create_social_subscription_request, _opts \\ []) do
    request =
      %{}
      |> method(:post)
      |> url("/social/subscription/#{network}/#{resource}/#{slug}/#{content}")
      |> add_param(:body, :body, create_social_subscription_request)
      |> Enum.into([])

    connection
    |> Connection.request(request)
    |> evaluate_response([
      {201, WelcomeToZembraAPIDocumentation.Model.CreateSocialSubscription201Response},
      {400, WelcomeToZembraAPIDocumentation.Model.GetSocialResourceDetails400Response},
      {401, WelcomeToZembraAPIDocumentation.Model.GetPropertyDetailsByName401Response},
      {402, WelcomeToZembraAPIDocumentation.Model.GetPropertyDetailsByName402Response},
      {403, WelcomeToZembraAPIDocumentation.Model.GetPropertyDetailsByName403Response},
      {404, WelcomeToZembraAPIDocumentation.Model.GetSocialResourceDetails404Response},
      {409, WelcomeToZembraAPIDocumentation.Model.CreateSocialSubscription409Response}
    ])
  end

  @doc """
  Delete Social Media Subscription by Slug
  Completely delete a subscription. This action is not reversible. In the scenario you re-request to create a subscription to the same social media resource, you will be charged a new fee like if the previous and deleted subscription had never existed. You will also immediately stop receiving updates. We will stop monitoring updates.

  ### Parameters

  - `connection` (WelcomeToZembraAPIDocumentation.Connection): Connection to server
  - `network` (SocialNetwork): Target social network
  - `resource` (Resource): Depending on the selected network, this will define what object you are trying to access details. <br><br>List of available resources varies by network: - **Better Business Bureau**:   - company - **Facebook**:   - advertiser   - page   - post - **Glassdoor**:   - company - **Instagram**:   - hashtag   - post   - user - **LinkedIn**:   - company   - keyword   - profile   - post - **Reddit**:   - keyword   - post   - subreddit   - user - **TikTok**:   - hashtag   - user   - video 
  - `slug` (String.t): Unique resource identifier. Full URLs are not accepted. Varies by network. Here are a few examples per resource: - **Better Business Bureau**:   - Company: good-greek-moving-storage-0633-90312345 - **Facebook**:   - Advertiser: 176105152520900   - Page: Presidence.tn   - Post: S:_I1391675561076747:3140064409571178 or 3140064409571178 or pfbid02ZZQHWhS4VQ3jwAN7FHbNtM5Hs1gAfkC6c6SoAkNvEsNNeY3e9gXVCKZPhg6WTnVTl - **Glassdoor**:   - Company: Working-at-Booz-Allen-Hamilton-EI_IE2735 - **Instagram**:   - Hashtag: coupleprayer   - Post: CFzAp7DASJ0   - User: soumaya_belkouchi - **LinkedIn**:   - Company: zembra   - Keyword: san+diego   - Profile: bakayoko   - Post: urn:li:ugcPost:6971444261015724033 - **Reddit**:   - Keyword: sandiego   - Post: 12mizot   - Subreddit: Damnthatsinteresting   - User: coastalJuncture - **TikTok**:   - Hashtag: healthy   - User: justqueen1988   - Video: 7114961878434041094 
  - `content` (Content): Depending on the selected network, this will define what data you want to stream. This is needed because under one source there could be more than one content type to be streamed. Example, for Instagram users, you may want to pull all comments or all reels.
  - `opts` (keyword): Optional parameters

  ### Returns

  - `{:ok, WelcomeToZembraAPIDocumentation.Model.DeleteSocialSubscriptionBySlug200Response.t}` on success
  - `{:error, Tesla.Env.t}` on failure
  """
  @spec delete_social_subscription_by_slug(Tesla.Env.client, WelcomeToZembraAPIDocumentation.Model.SocialNetwork.t, WelcomeToZembraAPIDocumentation.Model.Resource.t, String.t, WelcomeToZembraAPIDocumentation.Model.Content.t, keyword()) :: {:ok, WelcomeToZembraAPIDocumentation.Model.GetSocialResourceDetails400Response.t} | {:ok, WelcomeToZembraAPIDocumentation.Model.GetPropertyDetailsByName401Response.t} | {:ok, WelcomeToZembraAPIDocumentation.Model.FetchReviews404Response.t} | {:ok, WelcomeToZembraAPIDocumentation.Model.DeleteSocialSubscriptionBySlug200Response.t} | {:ok, WelcomeToZembraAPIDocumentation.Model.GetPropertyDetailsByName403Response.t} | {:error, Tesla.Env.t}
  def delete_social_subscription_by_slug(connection, network, resource, slug, content, _opts \\ []) do
    request =
      %{}
      |> method(:delete)
      |> url("/social/subscription/#{network}/#{resource}/#{slug}/#{content}")
      |> Enum.into([])

    connection
    |> Connection.request(request)
    |> evaluate_response([
      {200, WelcomeToZembraAPIDocumentation.Model.DeleteSocialSubscriptionBySlug200Response},
      {400, WelcomeToZembraAPIDocumentation.Model.GetSocialResourceDetails400Response},
      {401, WelcomeToZembraAPIDocumentation.Model.GetPropertyDetailsByName401Response},
      {403, WelcomeToZembraAPIDocumentation.Model.GetPropertyDetailsByName403Response},
      {404, WelcomeToZembraAPIDocumentation.Model.FetchReviews404Response}
    ])
  end

  @doc """
  Get Contents by job ID
  Returns the list of elements (posts, comments, etc.) that were collected as requested in the job.

  ### Parameters

  - `connection` (WelcomeToZembraAPIDocumentation.Connection): Connection to server
  - `job_id` (String.t): The ID of the job that was returned at the time of creating the job
  - `opts` (keyword): Optional parameters
    - `:limit` (integer()): Indicates the maximum number of elements to be returned. The default limit will be applied if omitted.
    - `:offset` (integer()): Helps with pagination. It indicates the offset to be applied to the set of elements.

  ### Returns

  - `{:ok, WelcomeToZembraAPIDocumentation.Model.GetSocialJobById200Response.t}` on success
  - `{:error, Tesla.Env.t}` on failure
  """
  @spec get_social_job_by_id(Tesla.Env.client, String.t, keyword()) :: {:ok, WelcomeToZembraAPIDocumentation.Model.GetPropertyDetailsByName401Response.t} | {:ok, WelcomeToZembraAPIDocumentation.Model.GetSocialJobById200Response.t} | {:ok, WelcomeToZembraAPIDocumentation.Model.GetPropertyDetailsByName400Response.t} | {:ok, WelcomeToZembraAPIDocumentation.Model.GetReviewJob404Response.t} | {:error, Tesla.Env.t}
  def get_social_job_by_id(connection, job_id, opts \\ []) do
    optional_params = %{
      :limit => :query,
      :offset => :query
    }

    request =
      %{}
      |> method(:get)
      |> url("/social/job/#{job_id}")
      |> add_optional_params(optional_params, opts)
      |> Enum.into([])

    connection
    |> Connection.request(request)
    |> evaluate_response([
      {200, WelcomeToZembraAPIDocumentation.Model.GetSocialJobById200Response},
      {206, WelcomeToZembraAPIDocumentation.Model.GetSocialJobById200Response},
      {400, WelcomeToZembraAPIDocumentation.Model.GetPropertyDetailsByName400Response},
      {401, WelcomeToZembraAPIDocumentation.Model.GetPropertyDetailsByName401Response},
      {404, WelcomeToZembraAPIDocumentation.Model.GetReviewJob404Response}
    ])
  end

  @doc """
  Get Social Media Jobs List
  Returns the list of social media jobs of the account. The result includes details about the job like requested time, internal ID, etc. The maximum number of returned jobs is 100 but you may use the `limit` and `offset` parameters for pagination.

  ### Parameters

  - `connection` (WelcomeToZembraAPIDocumentation.Connection): Connection to server
  - `opts` (keyword): Optional parameters
    - `:limit` (integer()): Maximum number of jobs to be returned. At most 100 jobs will be returned even if this parameter is set to a higher value.
    - `:offset` (integer()): Helps with pagination. It controls the offset to be applied to the set of jobs.
    - `:sortBy` (String.t): Indicates the desired sorting attribute
    - `:sortDirection` (String.t): Indicates the desired sorting direction.
    - `:internalId` (String.t): Filter results to only jobs with similar internal ID. This is the ID you set on the job that identifies it with your application. Please see the description of `internalId` in section **[GET] /social/{network}/{resource}/{slug}**.
    - `:slug` (String.t): Filter results to only jobs with similar slug. Please see the description of `slug` in section **[GET] /social/{network}/{resource}/{slug}**.
    - `:network` (SocialNetwork): Returns jobs only from the requested network.
    - `:resource` (Resource): Limits jobs to only those that match the selected resource type.
    - `:content` (Content): Limits jobs to only those that match the selected content type.
    - `:all` (boolean()): By default, the API will return the active and unexpired records. Setting this input to `true` will allow returning deleted and expired records.

  ### Returns

  - `{:ok, WelcomeToZembraAPIDocumentation.Model.GetSocialJobList200Response.t}` on success
  - `{:error, Tesla.Env.t}` on failure
  """
  @spec get_social_job_list(Tesla.Env.client, keyword()) :: {:ok, WelcomeToZembraAPIDocumentation.Model.GetPropertyDetailsByName401Response.t} | {:ok, WelcomeToZembraAPIDocumentation.Model.GetSocialJobList200Response.t} | {:ok, WelcomeToZembraAPIDocumentation.Model.GetPropertyDetailsByName400Response.t} | {:error, Tesla.Env.t}
  def get_social_job_list(connection, opts \\ []) do
    optional_params = %{
      :limit => :query,
      :offset => :query,
      :sortBy => :query,
      :sortDirection => :query,
      :internalId => :query,
      :slug => :query,
      :network => :query,
      :resource => :query,
      :content => :query,
      :all => :query
    }

    request =
      %{}
      |> method(:get)
      |> url("/social/jobs")
      |> add_optional_params(optional_params, opts)
      |> Enum.into([])

    connection
    |> Connection.request(request)
    |> evaluate_response([
      {200, WelcomeToZembraAPIDocumentation.Model.GetSocialJobList200Response},
      {400, WelcomeToZembraAPIDocumentation.Model.GetPropertyDetailsByName400Response},
      {401, WelcomeToZembraAPIDocumentation.Model.GetPropertyDetailsByName401Response}
    ])
  end

  @doc """
  Get Social Media Resource Details
  Returns details about social content like an Instagram post, TikTok video, LinkedIn post, etc. The response will include quasi-standard format across networks in addition to the original `rawData` collected from the source. Examples of collected data from an Instagram post are the slug, id, text, username, number of comments, number of likes, etc.

  ### Parameters

  - `connection` (WelcomeToZembraAPIDocumentation.Connection): Connection to server
  - `network` (SocialNetwork): Target social network
  - `resource` (Resource): Depending on the selected network, this will define what object you are trying to access details. <br><br>List of available resources varies by network: - **Better Business Bureau**:   - company - **Facebook**:   - advertiser   - page   - post - **Glassdoor**:   - company - **Instagram**:   - hashtag   - post   - user - **LinkedIn**:   - company   - keyword   - profile   - post - **Reddit**:   - keyword   - post   - subreddit   - user - **TikTok**:   - hashtag   - user   - video 
  - `slug` (String.t): Unique resource identifier. Full URLs are not accepted. Varies by network. Here are a few examples per resource: - **Better Business Bureau**:   - Company: good-greek-moving-storage-0633-90312345 - **Facebook**:   - Advertiser: 176105152520900   - Page: Presidence.tn   - Post: S:_I1391675561076747:3140064409571178 or 3140064409571178 or pfbid02ZZQHWhS4VQ3jwAN7FHbNtM5Hs1gAfkC6c6SoAkNvEsNNeY3e9gXVCKZPhg6WTnVTl - **Glassdoor**:   - Company: Working-at-Booz-Allen-Hamilton-EI_IE2735 - **Instagram**:   - Hashtag: coupleprayer   - Post: CFzAp7DASJ0   - User: soumaya_belkouchi - **LinkedIn**:   - Company: zembra   - Keyword: san+diego   - Profile: bakayoko   - Post: urn:li:ugcPost:6971444261015724033 - **Reddit**:   - Keyword: sandiego   - Post: 12mizot   - Subreddit: Damnthatsinteresting   - User: coastalJuncture - **TikTok**:   - Hashtag: healthy   - User: justqueen1988   - Video: 7114961878434041094 
  - `opts` (keyword): Optional parameters

  ### Returns

  - `{:ok, WelcomeToZembraAPIDocumentation.Model.GetSocialResourceDetails200Response.t}` on success
  - `{:error, Tesla.Env.t}` on failure
  """
  @spec get_social_resource_details(Tesla.Env.client, WelcomeToZembraAPIDocumentation.Model.SocialNetwork.t, WelcomeToZembraAPIDocumentation.Model.Resource.t, String.t, keyword()) :: {:ok, WelcomeToZembraAPIDocumentation.Model.GetPropertyDetailsByName402Response.t} | {:ok, WelcomeToZembraAPIDocumentation.Model.GetSocialResourceDetails400Response.t} | {:ok, WelcomeToZembraAPIDocumentation.Model.GetSocialResourceDetails404Response.t} | {:ok, WelcomeToZembraAPIDocumentation.Model.GetPropertyDetailsByName401Response.t} | {:ok, WelcomeToZembraAPIDocumentation.Model.GetSocialResourceDetails200Response.t} | {:ok, WelcomeToZembraAPIDocumentation.Model.GetPropertyDetailsByName403Response.t} | {:error, Tesla.Env.t}
  def get_social_resource_details(connection, network, resource, slug, _opts \\ []) do
    request =
      %{}
      |> method(:get)
      |> url("/social/#{network}/#{resource}/#{slug}")
      |> Enum.into([])

    connection
    |> Connection.request(request)
    |> evaluate_response([
      {200, WelcomeToZembraAPIDocumentation.Model.GetSocialResourceDetails200Response},
      {400, WelcomeToZembraAPIDocumentation.Model.GetSocialResourceDetails400Response},
      {401, WelcomeToZembraAPIDocumentation.Model.GetPropertyDetailsByName401Response},
      {402, WelcomeToZembraAPIDocumentation.Model.GetPropertyDetailsByName402Response},
      {403, WelcomeToZembraAPIDocumentation.Model.GetPropertyDetailsByName403Response},
      {404, WelcomeToZembraAPIDocumentation.Model.GetSocialResourceDetails404Response}
    ])
  end

  @doc """
  Get Contents by Slug
  Returns the list of elements for the requested resource along with details of the subscription. <br><br>If the data is fully loaded in our system, you will get a **200 OK**. However, if the pulling is still in progress, expect to get a **206 Partial Content**. This last response will include whatever data has been collected thus far. You can call this endpoint as many times as you want within the lifespan of the subscription. <br><br>If you have webhooks or listeners enabled, you will start receiving data in chunks right away. Contrary to reviews where the data is received as a summary or in a form of digests including all the reviews, with social streams the data is forwarded to your servers on the fly in chunks of 20 to 50 elements at a time. There are no daily digests or summaries. <br><br>Social networks operate differently compared to review networks. They apply a chaining mechanism even when using API integration. As a consequence, when requesting a stream of a large size, you may experience delay due to serial data sourcing. <br><br>Data retention is set to 5 days as the day this documentation is generated. During the data retention period, you can query the API as many times as you want to request the data without being charged. <br><br>We will monitor the requested resource for updates with a minimum rest time of 3 hours. <br><br>Contents are always returned sorted by timestamp descending. <br><br>If `sizeLimit` and/or `dateLimit` parameters are set, the streaming will be stopped as soon as one of the conditions is met. If none of these parameters is present, the streaming will continue until all content is downloaded. Omitting both parameters may cause your account to accrue large charges with busy sources. 

  ### Parameters

  - `connection` (WelcomeToZembraAPIDocumentation.Connection): Connection to server
  - `network` (SocialNetwork): Target social network
  - `resource` (Resource): Depending on the selected network, this will define what object you are trying to access details. <br><br>List of available resources varies by network: - **Better Business Bureau**:   - company - **Facebook**:   - advertiser   - page   - post - **Glassdoor**:   - company - **Instagram**:   - hashtag   - post   - user - **LinkedIn**:   - company   - keyword   - profile   - post - **Reddit**:   - keyword   - post   - subreddit   - user - **TikTok**:   - hashtag   - user   - video 
  - `slug` (String.t): Unique resource identifier. Full URLs are not accepted. Varies by network. Here are a few examples per resource: - **Better Business Bureau**:   - Company: good-greek-moving-storage-0633-90312345 - **Facebook**:   - Advertiser: 176105152520900   - Page: Presidence.tn   - Post: S:_I1391675561076747:3140064409571178 or 3140064409571178 or pfbid02ZZQHWhS4VQ3jwAN7FHbNtM5Hs1gAfkC6c6SoAkNvEsNNeY3e9gXVCKZPhg6WTnVTl - **Glassdoor**:   - Company: Working-at-Booz-Allen-Hamilton-EI_IE2735 - **Instagram**:   - Hashtag: coupleprayer   - Post: CFzAp7DASJ0   - User: soumaya_belkouchi - **LinkedIn**:   - Company: zembra   - Keyword: san+diego   - Profile: bakayoko   - Post: urn:li:ugcPost:6971444261015724033 - **Reddit**:   - Keyword: sandiego   - Post: 12mizot   - Subreddit: Damnthatsinteresting   - User: coastalJuncture - **TikTok**:   - Hashtag: healthy   - User: justqueen1988   - Video: 7114961878434041094 
  - `content` (Content): Depending on the selected network, this will define what data you want to stream. This is needed because under one source there could be more than one content type to be streamed. Example, for Instagram users, you may want to pull all comments or all reels.
  - `opts` (keyword): Optional parameters
    - `:limit` (integer()): Indicates the maximum number of elements to be returned. The default limit will be applied if omitted.
    - `:offset` (integer()): Helps with pagination. It indicates the offset to be applied to the set of elements.

  ### Returns

  - `{:ok, WelcomeToZembraAPIDocumentation.Model.GetSocialSubscriptionBySlug200Response.t}` on success
  - `{:error, Tesla.Env.t}` on failure
  """
  @spec get_social_subscription_by_slug(Tesla.Env.client, WelcomeToZembraAPIDocumentation.Model.SocialNetwork.t, WelcomeToZembraAPIDocumentation.Model.Resource.t, String.t, WelcomeToZembraAPIDocumentation.Model.Content.t, keyword()) :: {:ok, WelcomeToZembraAPIDocumentation.Model.GetSocialResourceDetails400Response.t} | {:ok, WelcomeToZembraAPIDocumentation.Model.GetPropertyDetailsByName401Response.t} | {:ok, WelcomeToZembraAPIDocumentation.Model.GetSocialSubscriptionBySlug200Response.t} | {:ok, WelcomeToZembraAPIDocumentation.Model.FetchReviews404Response.t} | {:ok, WelcomeToZembraAPIDocumentation.Model.GetPropertyDetailsByName403Response.t} | {:error, Tesla.Env.t}
  def get_social_subscription_by_slug(connection, network, resource, slug, content, opts \\ []) do
    optional_params = %{
      :limit => :query,
      :offset => :query
    }

    request =
      %{}
      |> method(:get)
      |> url("/social/subscription/#{network}/#{resource}/#{slug}/#{content}")
      |> add_optional_params(optional_params, opts)
      |> Enum.into([])

    connection
    |> Connection.request(request)
    |> evaluate_response([
      {200, WelcomeToZembraAPIDocumentation.Model.GetSocialSubscriptionBySlug200Response},
      {206, WelcomeToZembraAPIDocumentation.Model.GetSocialSubscriptionBySlug200Response},
      {400, WelcomeToZembraAPIDocumentation.Model.GetSocialResourceDetails400Response},
      {401, WelcomeToZembraAPIDocumentation.Model.GetPropertyDetailsByName401Response},
      {403, WelcomeToZembraAPIDocumentation.Model.GetPropertyDetailsByName403Response},
      {404, WelcomeToZembraAPIDocumentation.Model.FetchReviews404Response}
    ])
  end

  @doc """
  Get Social Media Subscriptions List
  Returns the list of social media subscriptions of the account. The result includes details about the subscription like requested time, internal ID, etc. The maximum number of returned subscriptions is 100 but you may use the `limit` and `offset` parameters for pagination.

  ### Parameters

  - `connection` (WelcomeToZembraAPIDocumentation.Connection): Connection to server
  - `opts` (keyword): Optional parameters
    - `:limit` (integer()): Maximum number of subscriptions to be returned. At most 100 subscriptions will be returned even if this parameter is set to a higher value.
    - `:offset` (integer()): Helps with pagination. It controls the offset to be applied to the set of subscriptions.
    - `:sortBy` (String.t): Indicates the desired sorting attribute.
    - `:sortDirection` (String.t): Indicates the desired sorting direction.
    - `:internalId` (String.t): Filter results to only subscriptions with similar internal ID. This is the ID you set on the subscription that identifies it in your application.
    - `:slug` (String.t): Filter results to only subscriptions to resources with similar slug.
    - `:network` (SocialNetwork): Returns subscriptions only from the requested network.
    - `:resource` (Resource): Limits subscriptions to only those that match the selected resource type.
    - `:content` (Content): Limits subscriptions to only those that match the selected content type.
    - `:all` (boolean()): By default, the API will return the active and unexpired records. Setting this input to `true` will allow returning deleted and expired records.

  ### Returns

  - `{:ok, WelcomeToZembraAPIDocumentation.Model.GetSocialSubscriptionList200Response.t}` on success
  - `{:error, Tesla.Env.t}` on failure
  """
  @spec get_social_subscription_list(Tesla.Env.client, keyword()) :: {:ok, WelcomeToZembraAPIDocumentation.Model.GetPropertyDetailsByName401Response.t} | {:ok, WelcomeToZembraAPIDocumentation.Model.GetSocialSubscriptionList200Response.t} | {:ok, WelcomeToZembraAPIDocumentation.Model.GetPropertyDetailsByName400Response.t} | {:error, Tesla.Env.t}
  def get_social_subscription_list(connection, opts \\ []) do
    optional_params = %{
      :limit => :query,
      :offset => :query,
      :sortBy => :query,
      :sortDirection => :query,
      :internalId => :query,
      :slug => :query,
      :network => :query,
      :resource => :query,
      :content => :query,
      :all => :query
    }

    request =
      %{}
      |> method(:get)
      |> url("/social/subscriptions")
      |> add_optional_params(optional_params, opts)
      |> Enum.into([])

    connection
    |> Connection.request(request)
    |> evaluate_response([
      {200, WelcomeToZembraAPIDocumentation.Model.GetSocialSubscriptionList200Response},
      {400, WelcomeToZembraAPIDocumentation.Model.GetPropertyDetailsByName400Response},
      {401, WelcomeToZembraAPIDocumentation.Model.GetPropertyDetailsByName401Response}
    ])
  end

  @doc """
  Update Social Media Subscription by Slug
  Introduces changes to an existing and active subscription to a social media resource.

  ### Parameters

  - `connection` (WelcomeToZembraAPIDocumentation.Connection): Connection to server
  - `network` (SocialNetwork): Target social network
  - `resource` (Resource): Depending on the selected network, this will define what object you are trying to access details. <br><br>List of available resources varies by network: - **Better Business Bureau**:   - company - **Facebook**:   - advertiser   - page   - post - **Glassdoor**:   - company - **Instagram**:   - hashtag   - post   - user - **LinkedIn**:   - company   - keyword   - profile   - post - **Reddit**:   - keyword   - post   - subreddit   - user - **TikTok**:   - hashtag   - user   - video 
  - `slug` (String.t): Unique resource identifier. Full URLs are not accepted. Varies by network. Here are a few examples per resource: - **Better Business Bureau**:   - Company: good-greek-moving-storage-0633-90312345 - **Facebook**:   - Advertiser: 176105152520900   - Page: Presidence.tn   - Post: S:_I1391675561076747:3140064409571178 or 3140064409571178 or pfbid02ZZQHWhS4VQ3jwAN7FHbNtM5Hs1gAfkC6c6SoAkNvEsNNeY3e9gXVCKZPhg6WTnVTl - **Glassdoor**:   - Company: Working-at-Booz-Allen-Hamilton-EI_IE2735 - **Instagram**:   - Hashtag: coupleprayer   - Post: CFzAp7DASJ0   - User: soumaya_belkouchi - **LinkedIn**:   - Company: zembra   - Keyword: san+diego   - Profile: bakayoko   - Post: urn:li:ugcPost:6971444261015724033 - **Reddit**:   - Keyword: sandiego   - Post: 12mizot   - Subreddit: Damnthatsinteresting   - User: coastalJuncture - **TikTok**:   - Hashtag: healthy   - User: justqueen1988   - Video: 7114961878434041094 
  - `content` (Content): Depending on the selected network, this will define what data you want to stream. This is needed because under one source there could be more than one content type to be streamed. Example, for Instagram users, you may want to pull all comments or all reels.
  - `update_social_subscription_by_slug_request` (UpdateSocialSubscriptionBySlugRequest): 
  - `opts` (keyword): Optional parameters

  ### Returns

  - `{:ok, WelcomeToZembraAPIDocumentation.Model.UpdateSocialSubscriptionBySlug200Response.t}` on success
  - `{:error, Tesla.Env.t}` on failure
  """
  @spec update_social_subscription_by_slug(Tesla.Env.client, WelcomeToZembraAPIDocumentation.Model.SocialNetwork.t, WelcomeToZembraAPIDocumentation.Model.Resource.t, String.t, WelcomeToZembraAPIDocumentation.Model.Content.t, WelcomeToZembraAPIDocumentation.Model.UpdateSocialSubscriptionBySlugRequest.t, keyword()) :: {:ok, WelcomeToZembraAPIDocumentation.Model.GetSocialResourceDetails400Response.t} | {:ok, WelcomeToZembraAPIDocumentation.Model.UpdateSocialSubscriptionBySlug200Response.t} | {:ok, WelcomeToZembraAPIDocumentation.Model.GetPropertyDetailsByName401Response.t} | {:ok, WelcomeToZembraAPIDocumentation.Model.FetchReviews404Response.t} | {:ok, WelcomeToZembraAPIDocumentation.Model.GetPropertyDetailsByName403Response.t} | {:error, Tesla.Env.t}
  def update_social_subscription_by_slug(connection, network, resource, slug, content, update_social_subscription_by_slug_request, _opts \\ []) do
    request =
      %{}
      |> method(:patch)
      |> url("/social/subscription/#{network}/#{resource}/#{slug}/#{content}")
      |> add_param(:body, :body, update_social_subscription_by_slug_request)
      |> Enum.into([])

    connection
    |> Connection.request(request)
    |> evaluate_response([
      {200, WelcomeToZembraAPIDocumentation.Model.UpdateSocialSubscriptionBySlug200Response},
      {400, WelcomeToZembraAPIDocumentation.Model.GetSocialResourceDetails400Response},
      {401, WelcomeToZembraAPIDocumentation.Model.GetPropertyDetailsByName401Response},
      {403, WelcomeToZembraAPIDocumentation.Model.GetPropertyDetailsByName403Response},
      {404, WelcomeToZembraAPIDocumentation.Model.FetchReviews404Response}
    ])
  end
end
