defmodule WelcomeToZembraAPIDocumentation.Mixfile do
  use Mix.Project

  def project do
    [
      app: :welcome_to_zembra_api_documentation,
      version: "1.0.0",
      elixir: "~> 1.10",
      build_embedded: Mix.env() == :prod,
      start_permanent: Mix.env() == :prod,
      package: package(),
      description: """
      Zembra provides a RESTful API that supports common HTTP verbs and returns JSON-formatted responses with common HTTP status codes. &lt;br&gt;&lt;br&gt;You can use the sandbox token and endpoints for testing. The sandbox environment is isolated and will not impact your account balance. Nevertheless, the same rate limiting applies to both live and sandbox environments combined. The sandbox randomly returns dummy data representing all different expected responses from an endpoint. The sandbox performs the same set of validation the live box does, including slug validation and eligibility for services. &lt;br&gt;&lt;br&gt;Default rate limiting is set to **100** requests per minute. This limit may vary based on your account settings. If unsure, contact your account manager or reach out to our [support team](mailto:contact@zembratech.com). &lt;br&gt;&lt;br&gt;Each response returned by the API has rate limiting info added to the headers: - **X-RateLimit-Limit**: 100 or -1 if no limit. &lt;br&gt;The allocated rate limit to the account. - **X-RateLimit-Remaining**: &lt; 100 or -1 if no limit. &lt;br&gt;The number of remaining calls before hitting the rate limiting limit and start getting calls rejected until the counter is reset.  Zembra has made SDKs available in many coding languages to help you quickly get started consuming the API with minimum effort: - [C-Sharp](https://cdn.sdks.zembratech.com/zembra-sdk-csharp.zip) - [Elixir](https://cdn.sdks.zembratech.com/zembra-sdk-elixir.zip) - [Go](https://cdn.sdks.zembratech.com/zembra-sdk-go.zip) - [Java](https://cdn.sdks.zembratech.com/zembra-sdk-java.zip) - [Javascript](https://cdn.sdks.zembratech.com/zembra-sdk-javascript.zip) - [Kotlin](https://cdn.sdks.zembratech.com/zembra-sdk-kotlin.zip) - [PHP](https://cdn.sdks.zembratech.com/zembra-sdk-php.zip) - [Python](https://cdn.sdks.zembratech.com/zembra-sdk-python.zip) - [Ruby on Rails](https://cdn.sdks.zembratech.com/zembra-sdk-ruby-on-rails.zip) - [Scala](https://cdn.sdks.zembratech.com/zembra-sdk-scala-akka.zip) - [Swift 5](https://cdn.sdks.zembratech.com/zembra-sdk-swift5.zip) - [Typescript](https://cdn.sdks.zembratech.com/zembra-sdk-typescript.zip)  You can also download [Postman](https://www.postman.com/downloads/) then import this [collection](https://cdn.sdks.zembratech.com/zembra-postman-collection.json) which includes calls the all Zembra API sandbox endpoints with a combination of all available parameters. 
      """,
      deps: deps()
    ]
  end

  # Configuration for the OTP application
  #
  # Type "mix help compile.app" for more information
  def application do
    # Specify extra applications you'll use from Erlang/Elixir
    [extra_applications: [:logger]]
  end

  # Dependencies can be Hex packages:
  #
  #   {:my_dep, "~> 0.3.0"}
  #
  # Or git/path repositories:
  #
  #   {:my_dep, git: "https://github.com/elixir-lang/my_dep.git", tag: "0.3.0"}
  #
  # Type "mix help deps" for more examples and options
  defp deps do
    [
      {:tesla, "~> 1.7"},
      {:jason, "~> 1.4"},
      {:ex_doc, "~> 0.30", only: :dev, runtime: false},
      {:dialyxir, "~> 1.3", only: [:dev, :test], runtime: false}
    ]
  end

   defp package do
      [
        name: "welcome_to_zembra_api_documentation",
        files: ~w(.formatter.exs config lib mix.exs README* LICENSE*),
      ]
  end
end
